@@ -5,21 +5,24 @@ import uuid
 import warnings
 from inspect import isclass
 
+from ipywidgets import widget_serialization
 import ipyvue
 
 from astropy.nddata import CCDData
 from echo import CallbackProperty, DictCallbackProperty, ListCallbackProperty
 from ipygoldenlayout import GoldenLayout
 from ipysplitpanes import SplitPanes
-from traitlets import Dict, Bool, Unicode
+from traitlets import Dict, Bool, Unicode, Any
 from specutils import Spectrum1D, SpectralRegion
+import matplotlib.cm as cm
 import numpy as np
 
 from glue.core.exceptions import IncompatibleAttribute
-from glue.config import data_translator
+from glue.config import colormaps, data_translator
 from glue.config import settings as glue_settings
 from glue.core import BaseData, HubListener, Data, DataCollection
 from glue.core.link_helpers import LinkSame
+from glue.plugins.wcs_autolinking.wcs_autolinking import WCSLink, IncompatibleWCS
 from glue.core.message import (DataCollectionAddMessage,
                                DataCollectionDeleteMessage)
 from glue.core.state_objects import State
@@ -40,6 +43,7 @@ from jdaviz.core.registries import (tool_registry, tray_registry, viewer_registr
                                     data_parser_registry)
 from jdaviz.core.tools import ICON_DIR
 from jdaviz.utils import SnackbarQueue
+from ipypopout import PopoutButton
 
 __all__ = ['Application']
 
@@ -65,12 +69,16 @@ custom_components = {'j-tooltip': 'components/tooltip.vue',
                      'j-play-pause-widget': 'components/play_pause_widget.vue',
                      'j-plugin-section-header': 'components/plugin_section_header.vue',
                      'j-number-uncertainty': 'components/number_uncertainty.vue',
+                     'j-plugin-popout': 'components/plugin_popout.vue',
                      'plugin-dataset-select': 'components/plugin_dataset_select.vue',
                      'plugin-subset-select': 'components/plugin_subset_select.vue',
                      'plugin-viewer-select': 'components/plugin_viewer_select.vue',
+                     'plugin-layer-select': 'components/plugin_layer_select.vue',
                      'plugin-add-results': 'components/plugin_add_results.vue',
-                     'plugin-auto-label': 'components/plugin_auto_label.vue'}
+                     'plugin-auto-label': 'components/plugin_auto_label.vue',
+                     'glue-state-sync-wrapper': 'components/glue_state_sync_wrapper.vue'}
 
+_verbosity_levels = ('debug', 'info', 'warning', 'error')
 
 # Register pure vue component. This allows us to do recursive component instantiation only in the
 # vue component file
@@ -93,6 +101,8 @@ class ApplicationState(State):
     """
     drawer = CallbackProperty(
         False, docstring="State of the plugins drawer.")
+    logger_overlay = CallbackProperty(
+        False, docstring="State of the logger history overlay.")
 
     snackbar = DictCallbackProperty({
         'show': False,
@@ -104,6 +114,8 @@ class ApplicationState(State):
 
     snackbar_queue = SnackbarQueue()
 
+    snackbar_history = ListCallbackProperty(docstring="Previously dismissed snackbar items")
+
     settings = DictCallbackProperty({
         'data': {
             'auto_populate': False,
@@ -164,10 +176,13 @@ class Application(VuetifyTemplate, HubListener):
     loading = Bool(False).tag(sync=True)
     config = Unicode("").tag(sync=True)
     vdocs = Unicode("").tag(sync=True)
+    popout_button = Any().tag(sync=True, **widget_serialization)
 
     def __init__(self, configuration=None, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self._verbosity = 'info'
+        self._verbosity = 'warning'
+        self._history_verbosity = 'info'
+        self.popout_button = PopoutButton(self)
 
         # Generate a state object for this application to maintain the state of
         #  the user interface.
@@ -234,6 +249,18 @@ class Application(VuetifyTemplate, HubListener):
         # Add a fitted_models dictionary that the helpers (or user) can access
         self.fitted_models = {}
 
+        # Add inverse colormaps to Glue global state. Also see ColormapRegistry in
+        # https://github.com/glue-viz/glue/blob/main/glue/config.py
+        new_cms = (['Reversed: Gray', cm.gray_r],
+                   ['Reversed: Viridis', cm.viridis_r],
+                   ['Reversed: Plasma', cm.plasma_r],
+                   ['Reversed: Inferno', cm.inferno_r],
+                   ['Reversed: Magma', cm.magma_r],
+                   ['Reversed: Hot', cm.hot_r])
+        for cur_cm in new_cms:
+            if cur_cm not in colormaps.members:
+                colormaps.add(*cur_cm)
+
     @property
     def hub(self):
         """
@@ -262,23 +289,38 @@ class Application(VuetifyTemplate, HubListener):
     @property
     def verbosity(self):
         """
-        Verbosity of the application, choose from ``'debug'``, ``'info'`` (default),
-        ``'warning'``, or ``'error'``.
+        Verbosity of the application for popup snackbars, choose from ``'debug'``,
+        ``'info'``, ``'warning'`` (default), or ``'error'``.
         """
         return self._verbosity
 
     @verbosity.setter
     def verbosity(self, val):
-        if val not in ('debug', 'info', 'warning', 'error'):
+        if val not in _verbosity_levels:
             raise ValueError(f'Invalid verbosity: {val}')
         self._verbosity = val
 
+    @property
+    def history_verbosity(self):
+        """
+        Verbosity of the logger history, choose from ``'debug'``, ``'info'`` (default),
+        ``'warning'``, or ``'error'``.
+        """
+        return self._history_verbosity
+
+    @history_verbosity.setter
+    def history_verbosity(self, val):
+        if val not in _verbosity_levels:
+            raise ValueError(f'Invalid verbosity: {val}')
+        self._history_verbosity = val
+
     def _on_snackbar_message(self, msg):
         """
         Displays a toast message with an editable message that be dismissed
         manually or will dismiss automatically after a timeout.
 
-        This is also controlled by ``self.verbosity``.
+        Whether the message shows as a snackbar popup is controlled by ``self.verbosity``,
+        whether the message is added to the history log is controlled by ``self.history_verbosity``.
 
         Parameters
         ----------
@@ -295,16 +337,21 @@ class Application(VuetifyTemplate, HubListener):
         # * info lets everything through
         # * success, secondary, and primary are treated as info (not sure what they are used for)
         # * None is also treated as info (when color is not set)
-        ignored = []
-        if self.verbosity in ('warning', 'error'):
-            ignored += ['success', 'info', 'secondary', 'primary', None]
-            if self.verbosity == 'error':
-                ignored.append('warning')
+        popup_level = _verbosity_levels.index(self.verbosity)
+        history_level = _verbosity_levels.index(self.history_verbosity)
 
-        if msg.color not in ignored:
-            self.state.snackbar_queue.put(self.state, msg)
+        def _color_to_level(color):
+            if color in _verbosity_levels:
+                return color
+            # could create dictionary mapping if we need anything more advanced
+            return 'info'
 
-    def _link_new_data(self):
+        msg_level = _verbosity_levels.index(_color_to_level(msg.color))
+        self.state.snackbar_queue.put(self.state, msg,
+                                      history=msg_level >= history_level,
+                                      popup=msg_level >= popup_level)
+
+    def _link_new_data(self, reference_data=None, data_to_be_linked=None):
         """
         When additional data is loaded, check to see if the spectral axis of
         any components are compatible with already loaded data. If so, link
@@ -312,42 +359,68 @@ class Application(VuetifyTemplate, HubListener):
         """
         if self.config == 'imviz':  # Imviz does its own thing
             return
-
-        new_len = len(self.data_collection)
-
-        # Allow for batch linking of data in the parser rather than on
-        # data load
-        if not self.auto_link or new_len < 2:
+        elif not self.auto_link:
             return
+        elif self.config == 'mosviz' and self.get_viewer('spectrum-viewer').state.reference_data:
+            # Mosviz turns auto_link to False in order to batch
+            # link the data after they have all been loaded.
+            # It then reverts auto_link to True, which means that when
+            # plugin data is added from mosviz, it can use the following line
+            # to set reference data.
+            reference_data = self.get_viewer('spectrum-viewer').state.reference_data.label
 
-        # Can't link if there's no world_component_ids
-        wc_new = self.data_collection[-1].world_component_ids
-        pc_new = self.data_collection[-1].pixel_component_ids
+        dc = self.data_collection
+        # This will need to be changed for cubeviz to support multiple cubes
+        ref_data = dc[reference_data] if reference_data else dc[0]
+        linked_data = dc[data_to_be_linked] if data_to_be_linked else dc[-1]
 
-        # Link to the first dataset with compatible coordinates
-        for i in range(new_len - 1):
-            wc_old = self.data_collection[i].world_component_ids
-            pc_old = self.data_collection[i].pixel_component_ids
+        try:
+            if linked_data.meta.get("Plugin", None) == 'GaussianSmooth':
+                raise AttributeError
+            dc.add_link(WCSLink(ref_data, linked_data))
+        except (AttributeError, IncompatibleWCS):
+            pc_ref = [str(id).split(" ")[-1][1] for id in ref_data.pixel_component_ids]
+            pc_linked = [str(id).split(" ")[-1][1] for id in linked_data.pixel_component_ids]
 
-            if wc_old == []:
-                continue
-            else:
-                # Link cubes to each other
-                if len(pc_old) > 2 and len(pc_new) > 2:
-                    links = [LinkSame(pc_old[1], pc_new[1]),
-                             LinkSame(pc_old[2], pc_new[2]),
-                             LinkSame(wc_old[0], wc_new[0])]
+            links = []
 
-                # If data is not a cube, use old linking method
-                elif len(wc_new) > 0:
-                    links = [LinkSame(wc_old[0], wc_new[0])]
+            # This code loops through the returned locations of the x, y, and z
+            # axes in the pixel_coordinate_ids of the reference data. It matches
+            # the axes with the pixel_coordinate_ids of the linked data and links
+            # those axes. There are special rules for linking 2D and 3D data, which
+            # is as follows: 2D y to 3D z and 2D x to 3D y, and vice versa in the
+            # case of moment map and collapse data because they need to be transposed.
+            # See github comment:
+            # https://github.com/spacetelescope/jdaviz/pull/1412#discussion_r907630682
+            len_linked_pixel = len(linked_data.pixel_component_ids)
 
+            for ind, pixel_coord in enumerate(pc_ref):
+                ref_index = ind
+                if (len_linked_pixel == 2 and
+                        (linked_data.meta.get("Plugin", None) in
+                         ['MomentMap', 'Collapse'])):
+                    if pixel_coord == 'z':
+                        linked_index = pc_linked.index('x')
+                    elif pixel_coord == 'y':
+                        linked_index = pc_linked.index('y')
+                    else:
+                        continue
+                elif len_linked_pixel == 2:
+                    if pixel_coord == 'z':
+                        linked_index = pc_linked.index('y')
+                    elif pixel_coord == 'y':
+                        linked_index = pc_linked.index('x')
+                    else:
+                        continue
+                elif pixel_coord in pc_linked:
+                    linked_index = pc_linked.index(pixel_coord)
                 else:
-                    break
+                    continue
 
-                self.data_collection.add_link(links)
+                links.append(LinkSame(ref_data.pixel_component_ids[ref_index],
+                                      linked_data.pixel_component_ids[linked_index]))
 
-                break
+            dc.add_link(links)
 
     def load_data(self, file_obj, parser_reference=None, **kwargs):
         """
@@ -830,13 +903,13 @@ class Application(VuetifyTemplate, HubListener):
         data_id = self._data_id_from_label(data_label)
 
         if clear_other_data:
-            self._update_selected_data_items(viewer_item['id'], [])
+            self._update_selected_data_items(viewer_item['id'], {})
 
-        data_ids = viewer_item['selected_data_items']
+        selected_data_items = viewer_item['selected_data_items']
 
         if data_id is not None:
-            data_ids.append(data_id)
-            self._update_selected_data_items(viewer_item['id'], data_ids)
+            selected_data_items[data_id] = 'visible'
+            self._update_selected_data_items(viewer_item['id'], selected_data_items)
         else:
             raise ValueError(
                 f"No data item found with label '{data_label}'. Label must be one "
@@ -878,10 +951,10 @@ class Application(VuetifyTemplate, HubListener):
         selected_items = viewer_item['selected_data_items']
 
         if data_id in selected_items:
-            selected_items.remove(data_id)
+            _ = selected_items.pop(data_id)
 
-            self._update_selected_data_items(
-                viewer_item['id'], selected_items)
+        self._update_selected_data_items(
+            viewer_item['id'], selected_items)
 
     def _data_id_from_label(self, label):
         """
@@ -1109,12 +1182,24 @@ class Application(VuetifyTemplate, HubListener):
             raise ValueError(f'viewer {viewer_id} not found')
 
         if replace:
-            selected_items = [item_id]
+            selected_items = {item_id: 'visible'}
         elif checked:
-            selected_items = [*viewer_item['selected_data_items'], item_id]
+            selected_items = {**viewer_item['selected_data_items'], item_id: 'visible'}
         else:
-            selected_items = list(filter(
-                lambda id: id != item_id, viewer_item['selected_data_items']))
+            selected_items = {k: v for k, v in viewer_item['selected_data_items'].items() if k != item_id}  # noqa
+
+        self._update_selected_data_items(viewer_id, selected_items)
+
+    def vue_data_item_visibility(self, event):
+        viewer_id, item_id, visible = event['id'], event['item_id'], event['visible']
+        viewer_item = self._viewer_item_by_id(viewer_id)
+
+        replace = event.get('replace', False)
+        selected_items = viewer_item['selected_data_items']
+        if replace and visible:
+            selected_items = {id: 'visible' if id == item_id else 'hidden' for id in selected_items.keys()}  # noqa
+        else:
+            selected_items[item_id] = 'visible' if visible else 'hidden'
 
         self._update_selected_data_items(viewer_id, selected_items)
 
@@ -1139,14 +1224,15 @@ class Application(VuetifyTemplate, HubListener):
         viewer_item = self._viewer_item_by_id(viewer_id)
         viewer = self._viewer_by_id(viewer_id)
 
+        if isinstance(selected_items, list):
+            selected_items = {si: 'visible' for si in selected_items}
         # Update the stored selected data items
         viewer_item['selected_data_items'] = selected_items
-        data_ids = viewer_item['selected_data_items']
 
         active_data_labels = []
 
         # Include any selected data in the viewer
-        for data_id in data_ids:
+        for data_id, visibility in selected_items.items():
             label = next((x['name'] for x in self.state.data_items
                           if x['id'] == data_id), None)
 
@@ -1159,13 +1245,21 @@ class Application(VuetifyTemplate, HubListener):
 
             [data] = [x for x in self.data_collection if x.label == label]
 
-            viewer.add_data(data)
+            viewer.add_data(data, percentile=95)
 
             add_data_message = AddDataMessage(data, viewer,
                                               viewer_id=viewer_id,
                                               sender=self)
             self.hub.broadcast(add_data_message)
 
+            for layer in viewer.layers:
+                if layer.layer.data.label == label:
+                    if visibility == 'visible' and not layer.visible:
+                        layer.visible = True
+                        layer.update()
+                    else:
+                        layer.visible = visibility == 'visible'
+
         # Remove any deselected data objects from viewer
         viewer_data = [layer_state.layer
                        for layer_state in viewer.state.layers
@@ -1188,13 +1282,7 @@ class Application(VuetifyTemplate, HubListener):
                     and active_data._preferred_translation is not None):
                 self._set_plot_axes_labels(viewer_id)
 
-            # Make everything visible again in Imviz.
             if self.config == 'imviz':
-                from jdaviz.configs.imviz.helper import layer_is_image_data
-
-                for lyr in viewer.state.layers:
-                    if layer_is_image_data(lyr.layer):
-                        lyr.visible = True
                 viewer.on_limits_change()  # Trigger compass redraw
 
     def _on_data_added(self, msg):
@@ -1351,7 +1439,7 @@ class Application(VuetifyTemplate, HubListener):
             'layer_options': "IPY_MODEL_" + viewer.layer_options.model_id,
             'viewer_options': "IPY_MODEL_" + viewer.viewer_options.model_id,
             'layer_viewer_open': False,
-            'selected_data_items': [],
+            'selected_data_items': {},
             'config': self.config,  # give viewer access to app config/layout
             'data_open': False,
             'collapse': True,
