@@ -1,5 +1,6 @@
 import numpy as np
 
+from glue.core import BaseData
 from jdaviz.core.helpers import ConfigHelper
 from jdaviz.configs.default.plugins.line_lists.line_list_mixin import LineListMixin
 from jdaviz.configs.specviz import Specviz
@@ -75,7 +76,7 @@ class Cubeviz(ConfigHelper, LineListMixin):
     @property
     def specviz(self):
         """
-        A specviz helper (`~jdaviz.configs.specviz.Specviz`) for the Jdaviz
+        A specviz helper (`~jdaviz.configs.specviz.helper.Specviz`) for the Jdaviz
         application that is wrapped by cubeviz
         """
         if not hasattr(self, '_specviz'):
@@ -88,3 +89,7 @@ class Cubeviz(ConfigHelper, LineListMixin):
 class CubeViz(Cubeviz):
     """This class is pending deprecation. Please use `Cubeviz` instead."""
     pass
+
+
+def layer_is_cube_image_data(layer):
+    return isinstance(layer, BaseData) and layer.ndim in (2, 3)
