@@ -5,6 +5,7 @@ from glue_jupyter.bqplot.image import BqplotImageView
 from jdaviz.core.registries import viewer_registry
 from jdaviz.core.marks import SliceIndicatorMarks
 from jdaviz.configs.default.plugins.viewers import JdavizViewerMixin
+from jdaviz.configs.cubeviz.helper import layer_is_cube_image_data
 from jdaviz.configs.imviz.helper import data_has_valid_wcs
 from jdaviz.configs.specviz.plugins.viewers import SpecvizProfileView
 
@@ -18,17 +19,18 @@ class CubevizImageView(BqplotImageView, JdavizViewerMixin):
     # ones are added in glue-jupyter in future that we don't want here.
     inherit_tools = False
 
-    tools = ['bqplot:home', 'jdaviz:boxzoom',
-             'bqplot:panzoom', 'bqplot:rectangle',
-             'bqplot:circle']
+    tools = ['jdaviz:homezoom', 'jdaviz:boxzoom',
+             'jdaviz:panzoom', 'bqplot:rectangle',
+             'bqplot:circle', 'jdaviz:spectrumperspaxel']
 
     # categories: zoom resets, (zoom, pan), subset, select tools, shortcuts
     # NOTE: zoom and pan are merged here for space consideration and to avoid
     # overflow to second row when opening the tray
     tools_nested = [
-                    ['bqplot:home'],
-                    ['jdaviz:boxzoom', 'bqplot:panzoom'],
+                    ['jdaviz:homezoom', 'jdaviz:prevzoom'],
+                    ['jdaviz:boxzoom', 'jdaviz:panzoom'],
                     ['bqplot:circle', 'bqplot:rectangle'],
+                    ['jdaviz:spectrumperspaxel'],
                     ['jdaviz:sidebar_plot', 'jdaviz:sidebar_export']
                 ]
 
@@ -36,6 +38,7 @@ class CubevizImageView(BqplotImageView, JdavizViewerMixin):
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
+        self._subscribe_to_layers_update()
         self._initialize_toolbar_nested()
         self.state.add_callback('reference_data', self._initial_x_axis)
 
@@ -46,7 +49,8 @@ class CubevizImageView(BqplotImageView, JdavizViewerMixin):
     def on_mouse_or_key_event(self, data):
 
         # Find visible layers
-        visible_layers = [layer for layer in self.state.layers if layer.visible]
+        visible_layers = [layer for layer in self.state.layers
+                          if (layer.visible and layer_is_cube_image_data(layer.layer))]
 
         if len(visible_layers) == 0:
             return
@@ -64,7 +68,8 @@ class CubevizImageView(BqplotImageView, JdavizViewerMixin):
 
             # Extract first dataset from visible layers and use this for coordinates - the choice
             # of dataset shouldn't matter if the datasets are linked correctly
-            image = visible_layers[0].layer
+            active_layer = visible_layers[-1]
+            image = active_layer.layer
 
             # Extract data coordinates - these are pixels in the reference image
             x = data['domain']['x']
@@ -93,8 +98,8 @@ class CubevizImageView(BqplotImageView, JdavizViewerMixin):
             # Extract data values at this position.
             # Check if shape is [x, y, z] or [x, y] and show value accordingly.
             if (-0.5 < x < image.shape[0] - 0.5 and -0.5 < y < image.shape[1] - 0.5
-                    and hasattr(visible_layers[0], 'attribute')):
-                attribute = visible_layers[0].attribute
+                    and hasattr(active_layer, 'attribute')):
+                attribute = active_layer.attribute
                 if len(image.shape) == 3:
                     value = image.get_data(attribute)[int(round(x)), int(round(y)),
                                                       self.state.slices[-1]]
@@ -149,17 +154,17 @@ class CubevizProfileView(SpecvizProfileView):
     # ones are added in glue-jupyter in future that we don't want here.
     inherit_tools = False
 
-    tools = ['bqplot:home',
+    tools = ['jdaviz:homezoom',
              'jdaviz:boxzoom', 'jdaviz:xrangezoom',
-             'bqplot:panzoom', 'bqplot:panzoom_x',
-             'bqplot:panzoom_y', 'bqplot:xrange',
+             'jdaviz:panzoom', 'jdaviz:panzoom_x',
+             'jdaviz:panzoom_y', 'bqplot:xrange',
              'jdaviz:selectslice', 'jdaviz:selectline']
 
     # categories: zoom resets, zoom, pan, subset, select tools, shortcuts
     tools_nested = [
-                    ['bqplot:home'],
-                    ['jdaviz:xrangezoom', 'jdaviz:boxzoom'],
-                    ['bqplot:panzoom', 'bqplot:panzoom_x', 'bqplot:panzoom_y'],
+                    ['jdaviz:homezoom', 'jdaviz:prevzoom'],
+                    ['jdaviz:boxzoom', 'jdaviz:xrangezoom'],
+                    ['jdaviz:panzoom', 'jdaviz:panzoom_x', 'jdaviz:panzoom_y'],
                     ['bqplot:xrange'],
                     ['jdaviz:selectslice', 'jdaviz:selectline'],
                     ['jdaviz:sidebar_plot', 'jdaviz:sidebar_export']
