@@ -892,7 +892,7 @@ class Mosviz(ConfigHelper, LineListMixin):
     @property
     def specviz(self):
         """
-        A specviz helper (`~jdaviz.configs.specviz.Specviz`) for the Jdaviz
+        A specviz helper (`~jdaviz.configs.specviz.helper.Specviz`) for the Jdaviz
         application that is wrapped by mosviz
         """
         if not hasattr(self, '_specviz'):
@@ -902,7 +902,7 @@ class Mosviz(ConfigHelper, LineListMixin):
     @property
     def specviz2d(self):
         """
-        A specviz2d helper (`~jdaviz.configs.specviz2d.Specviz2d`) for the Jdaviz
+        A specviz2d helper (`~jdaviz.configs.specviz2d.helper.Specviz2d`) for the Jdaviz
         application that is wrapped by mosviz
         """
         if not hasattr(self, '_specviz2d'):
